Utilisation du script d'import d'emails dans une instance CubicWeb
Author: Logilab
Keywords: logilab

| Utilisation du script d'import d'emails dans une instance CubicWeb

| Utilisation du script d'import d'emails dans une instance CubicWeb Title underline too short. Utilisation du script d'import d'emails dans une instance CubicWeb --------------------------------------------------------------- 1. Conditions Le composant cubicweb-email doit être installés pour cette instance Pyro doit être activé pour cette instance 2. Utilisation en ligne de commande La commande mboximport de cubicweb-ctl permet d'importer un fichier au format Unix Mailbox. Il suffit de l'appeler en lui donnant en argument l'identifiant de l'application et le fichier à importer. Par défaut votre nom d'utilisateur sera utilisé pour se connecter à l'application, mais vous pouvez en spécifier un autre avec l'option -u. 3. Configuration mutt Dans le fichier .muttrc, ajouter par exemple la ligne : macro index "\ez" "<pipe-message>cubicweb-ctl mboximport -u ocy -p ocy drh -<enter>" et à partir de là vous pouvez faire "Alt-z" dans la vue d'index pour importer l'email séléctionné dans l'instance. L'exemple ci-dessus suppose que : l'identifiant pyro de l'application est "drh" Vous utilisez un compte ocy / ocy Donner le mot de passe en ligne de commande est nécessaire car on ne sait pas le lire correctement de manière interactive quand mutt lance la commande.